@@ -1,7 +1,7 @@
 package Bencher;
 
-our $DATE = '2016-01-21'; # DATE
-our $VERSION = '0.32'; # VERSION
+our $DATE = '2016-01-22'; # DATE
+our $VERSION = '0.33'; # VERSION
 
 use 5.010001;
 use strict;
@@ -950,6 +950,7 @@ $SPEC{bencher} = {
     summary => 'A benchmark framework',
     args_rels => {
         # XXX precision & precision_limit is only relevant when action=bench
+        # XXX note is only relevant when action=bench
     },
     args => {
         scenario_file => {
@@ -1324,6 +1325,11 @@ warning to STDERR and continue.
 
 _
         },
+
+        note => {
+            summary => 'Put additional note in the result',
+            schema => 'str*',
+        },
     },
 };
 sub bencher {
@@ -1750,6 +1756,7 @@ sub bencher {
                 Devel::Platform::Info->new->get_info;
             my $info = Sys::Info->new;
             $envres->[3]{'func.cpu_info'} = [$info->device('CPU')->identify];
+            $envres->[3]{'func.note'} = $args{note} if exists $args{note};
         }
 
       RETURN_RESULT:
@@ -1806,7 +1813,7 @@ Bencher - A benchmark framework
 
 =head1 VERSION
 
-This document describes version 0.32 of Bencher (from Perl distribution Bencher), released on 2016-01-21.
+This document describes version 0.33 of Bencher (from Perl distribution Bencher), released on 2016-01-22.
 
 =head1 SYNOPSIS
 
@@ -2221,6 +2228,10 @@ Only include participants whose seq/name matches this.
 
 Benchmark module startup overhead instead of normal benchmark.
 
+=item * B<note> => I<str>
+
+Put additional note in the result.
+
 =item * B<on_failure> => I<str>
 
 What to do when there is a failure.
